# ESPU Extension

This package is an extension for the **ESPU** ecosystem.

It is not intended to be used standalone.

## Installation

Install via the core package:

pip install espu

Or install with extras:

pip install espu[<extension>]

## Links

Core package:
https://pypi.org/project/espu/
https://github.com/EscapedShadows/ESPU